..
    Copyright (C) 2020 CERN.

    Flask-Resources is free software; you can redistribute it and/or
    modify it under the terms of the MIT License; see LICENSE file for more
    details.

===================
 Flask-Resources
===================

.. image:: https://img.shields.io/travis/inveniosoftware/flask-resources.svg
        :target: https://travis-ci.org/inveniosoftware/flask-resources

.. image:: https://img.shields.io/coveralls/inveniosoftware/flask-resources.svg
        :target: https://coveralls.io/r/inveniosoftware/flask-resources

.. image:: https://img.shields.io/github/tag/inveniosoftware/flask-resources.svg
        :target: https://github.com/inveniosoftware/flask-resources/releases

.. image:: https://img.shields.io/pypi/dm/flask-resources.svg
        :target: https://pypi.python.org/pypi/flask-resources

.. image:: https://img.shields.io/github/license/inveniosoftware/flask-resources.svg
        :target: https://github.com/inveniosoftware/flask-resources/blob/master/LICENSE

Flask Resources module to create REST APIs.

Further documentation is available on
https://flask-resources.readthedocs.io/
